View source: R/plot_AHP_decision_tree.R
| plot.AHP.decision.tree | R Documentation |
Plot decision tree
## S3 method for class 'AHP.decision.tree'
plot(
x,
comparing.competitors,
results,
vertex_font = 1.2,
edge_font = 1,
asp = 0.8,
max_width = 5,
vertex_size = 50,
...
)
x |
the comparison matrix |
comparing.competitors |
the list of matrices related to pairwise comparisons of competitors for each criteria |
results |
results of running AHP on data |
vertex_font |
font of text on vertex |
edge_font |
size of the arrows |
asp |
aspect ratio of the graph |
max_width |
maximum width |
vertex_size |
vertex size |
... |
further arguments passed to or from other methods |
the decision tree plot
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.